module Seer
  # DNS API controller
  class DNS
    # Initialize a DNS object
    # @param token [string] API token
    # @param version [string] API version you want use (defaut 1)
    # @param host [string] API host
    def initialize(token: '', version: '2.0', host: '')
      @host = host + '/dns'
      @header = {
          content_type: 'application/json',
          x_seer_token: token,
          x_seer_version: version
      }
    end

    # Get ip from domain
    # @param domain [string]
    # @return [Hash] Result
    def domain(domain)
      body = { domain: domain }
      url = @host + '/domain'
      Seer.request(url, body, @header)
    end

    # Get sub domain from domain
    # @param subdomain [string]
    # @return [Hash] Result
    def subdomain(subdomain)
      body = { domain: subdomain }
      url = @host + '/subdomain'
      Seer.request(url, body, @header)
    end

    # Get domain by ip
    # @param ip [String]
    # @return [Hash] Result
    def ip(ip)
      body = { ip: ip }
      url = @host + '/ip'
      Seer.request(url, body, @header)
    end

    # Advance search
    # @param type [string] DNS type
    # @param key [string] Key
    # @return [Hash] Result
    def search(type, key)
      body = {
          type: type,
          key: key
      }
      url = @host + '/search'
      Seer.request(url, body, @header)
    end
  end
end
