module Seer
  # Hosts API controller
  class Hosts
    # Initialize a Hosts object
    # @param token [string] API token
    # @param version [string] API version you want use (defaut 1)
    # @param host [string] API host
    def initialize(token: '', version: '2.0', host: '')
      @host = host + '/hosts'
      @header = {
          content_type: 'application/json',
          x_seer_token: token,
          x_seer_version: version
      }
    end

    # Get host by ip
    # @param ip [String] IP Address
    # @param minify [Boolean] Only return IP address (default false)
    # @return [Hash] Result
    def ip(ip, minify: false)
      body = {
        ip: ip,
        minify: minify
      }
      url = @host + '/ip'

      Seer.request(url, body, @header)
    end

    # Get hosts by port
    # @param port [Fixnum] Port you want to search
    # @param page [Fixnum] The page of results
    # @param minify [Boolean] Only return IP address (default false)
    # @return [Hash] Result
    def port(port, page: 1, minify: false)
      body = {
        port: port,
        page: page,
        minify: minify
      }
      url = @host + '/port'

      Seer.request(url, body, @header)
    end

    # Get hosts by service
    # @param service [String] Service you want to search
    # @param page [Fixnum] The page of results
    # @param minify [Boolean] Only return IP address (default false)
    # @return [Hash] Result
    def service(service, page: 1, minify: false)
      body = {
        service: service,
        page: page,
        minify: minify
      }
      url = @host + '/service'

      Seer.request(url, body, @header)
    end

    # Get hosts by custom search
    # @param query [String] Custom query
    # @param page [Fixnum] The page of results
    # @param minify [Boolean] Only return IP address (default false)
    # @return [Hash] Result
    def search(query, page: 1, minify: false)
      body = {
        query: query,
        page: page,
        minify: minify
      }
      url = @host + '/search'

      Seer.request(url, body, @header)
    end

    # Aggregations by query and field
    # @param query [String] Custom query
    # @param fields [String] The field you want to aggs
    # @return [Hash] Result
    def aggs(query, fields)
      body = {
        query: query,
        fields: fields
      }
      url = @host + '/aggs'

      Seer.request(url, body, @header)
    end
  end
end
