module Seer
  # ORG API controller
  class Org
    # Initialize a Org object
    # @param token [string]  API token
    # @param version [string] :version ('1') API version you want use (defaut 1)
    # @param host [string] API host (default http://seer.intra.nsfocus.com:8000/api)
    def initialize(token: '', version: '2.0', host: '')
      @host = host + '/org'
      @header = {
          content_type: 'application/json',
          x_seer_token: token,
          x_seer_version: version
      }
    end

    # Get organization by ip
    # @param ip [String] IP address for search
    # @return [Hash] Result
    def ip(ip)
      body = { ip: ip }
      url = @host + '/ip'

      Seer.request(url, body, @header)
    end

    # Get organization by AS number
    # @param asn [Fixnum] AS number
    # @return [Hash] Result
    def asn(asn)
      body = { asn: asn }
      url = @host + '/asn'

      Seer.request(url, body, @header)
    end
  end
end
