module Seer
  # Status API controller
  class Status
    # Initialize a Status object
    # @param token [string] API token
    # @param version [string] :version ('1') API version you want use (defaut 1)
    # @param host [string] API host (default http://seer.intra.nsfocus.com:8000/api)
    def initialize(token: '', version: '2.0', host: '')
      @host = host + '/status'
      @header = {
        content_type: 'application/json',
        x_seer_token: token,
        x_seer_version: version
      }
    end

    # Get SEER supported service
    # @return [Hash] Result
    def services
      url = @host + '/services'
      response = RestClient.get url, @header
      JSON.load response
    end

    # Get all ports
    # @return [Hash] Result
    def ports
      url = @host + '/ports'
      response = RestClient.get url, @header
      JSON.load response
    end

    # Get token status
    # @return [Hash] Result
    def token
      url = @host + "/token?token=#{@header[:x_seer_token]}"
      response = RestClient.get url, @header
      JSON.load response
    end
  end
end
